==> libcanberra-0.22-x86_64-3gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libcanberra.so )
( cd usr/lib64 ; ln -sf libcanberra.so.0.2.1 libcanberra.so )
( cd usr/lib64 ; rm -rf libcanberra-gtk.so )
( cd usr/lib64 ; ln -sf libcanberra-gtk.so.0.1.5 libcanberra-gtk.so )
( cd usr/lib64 ; rm -rf libltdl.so.7 )
( cd usr/lib64 ; ln -sf libltdl.so.7.2.0 libltdl.so.7 )
( cd usr/lib64 ; rm -rf libcanberra.so.0 )
( cd usr/lib64 ; ln -sf libcanberra.so.0.2.1 libcanberra.so.0 )
( cd usr/lib64 ; rm -rf libcanberra-gtk.so.0 )
( cd usr/lib64 ; ln -sf libcanberra-gtk.so.0.1.5 libcanberra-gtk.so.0 )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf power-unplug.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-removed.oga power-unplug.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf screen-capture.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf camera-shutter.oga screen-capture.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf dialog-error.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga dialog-error.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf window-question.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga window-question.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf window-attention.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga window-attention.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf network-connectivity-established.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-added.oga network-connectivity-established.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf network-connectivity-lost.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-removed.oga network-connectivity-lost.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf power-plug.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-added.oga power-plug.oga )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/libcanberra.schemas >/dev/null 2>&1
fi

==> libcanberra-0.24-x86_64-2gsb.txz: install/doinst.sh <==
( cd usr/share/sounds/freedesktop/stereo ; rm -rf screen-capture.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf camera-shutter.oga screen-capture.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf power-plug.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-added.oga power-plug.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf dialog-error.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga dialog-error.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf window-question.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga window-question.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf network-connectivity-lost.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-removed.oga network-connectivity-lost.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf window-attention.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf dialog-warning.oga window-attention.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf network-connectivity-established.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-added.oga network-connectivity-established.oga )
( cd usr/share/sounds/freedesktop/stereo ; rm -rf power-unplug.oga )
( cd usr/share/sounds/freedesktop/stereo ; ln -sf device-removed.oga power-unplug.oga )
( cd usr/lib64 ; rm -rf libcanberra-gtk.so.0 )
( cd usr/lib64 ; ln -sf libcanberra-gtk.so.0.1.6 libcanberra-gtk.so.0 )
( cd usr/lib64 ; rm -rf libcanberra-gtk.so )
( cd usr/lib64 ; ln -sf libcanberra-gtk.so.0.1.6 libcanberra-gtk.so )
( cd usr/lib64 ; rm -rf libcanberra.so.0 )
( cd usr/lib64 ; ln -sf libcanberra.so.0.2.3 libcanberra.so.0 )
( cd usr/lib64 ; rm -rf libcanberra.so )
( cd usr/lib64 ; ln -sf libcanberra.so.0.2.3 libcanberra.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/libcanberra.schemas >/dev/null 2>&1
fi
